﻿using System.Transactions;

using Demo1.Models;

using Mindscape.LightSpeed;

using NUnit.Framework;

namespace Tests
{
  /// <summary>
  /// This test class shows how to simply unit test a model class. The important
  /// parts here are the SetUp and TearDown methods which wrap the test itself in
  /// a transaction so data is not actually update the database at the end.
  /// </summary>
  
  [TestFixture]
  public class ModelTests
  {
    #region Setup/Teardown

    [SetUp]
    public void SetUp()
    {
      // Setup LightSpeed manually
      LightSpeedContext.ConnectionString = @"Server=.\SQLEXPRESS; Database=SimpleTaskTracker;Integrated Security=SSPI;";
      LightSpeedContext.DataProvider = DataProvider.SqlServer2005;
      LightSpeedContext.IdentityMethod = IdentityMethod.IdentityColumn;

      _transactionScope = new TransactionScope();
    }

    [TearDown]
    public void TearDown()
    {
      Repository.CompleteUnitOfWork(false);

      _transactionScope.Dispose();
    }

    #endregion

    private TransactionScope _transactionScope;

    [Test]
    public void PersonTest()
    {
      Person person = new Person();
      person.Name = "Andrew";
      person.EmailAddress = "andrew@mindscape.co.nz";

      Repository.Add(person);
      Repository.SaveChanges(true);

      Person theNewPerson = Repository.FindOne<Person>(person.Id);

      Assert.AreNotSame(person, theNewPerson);
      Assert.AreEqual("Andrew", theNewPerson.Name);
    }
  }
}