﻿using System.Web.Mvc;

using Demo1.Controllers;

using NUnit.Framework;

using Rhino.Mocks;

namespace Tests
{
  /// <summary>
  /// This test also tests the view being asked to render by a controller. This time
  /// we mock out httpContext and use a FakeViewEngine to allow testing without needing
  /// to subclass Controller. Much nicer :-)
  /// </summary>
  [TestFixture]
  public class RenderTests2
  {
    [Test]
    public void RenderViewTests()
    {
      TaskController tasks = new TaskController();
      FakeViewEngine ve = new FakeViewEngine();

      tasks.ViewEngine = ve;

      MockRepository mocks = new MockRepository();

      using (mocks.Record())
      {
        mocks.SetFakeControllerContext(tasks);
      }

      using (mocks.Playback())
      {
        tasks.Index();
        Assert.AreEqual("Index", ve.Context.ViewName);
      }
    }
  }

  public class FakeViewEngine : IViewEngine
  {
    public ViewContext Context { get; private set; }

    #region IViewEngine Members

    public void RenderView(ViewContext viewContext)
    {
      Context = viewContext;
    }

    #endregion
  }
}